[![CI / CD](https://github.com/software-students-spring2024/3-python-package-exercise-bestswe/actions/workflows/build.yaml/badge.svg)](https://github.com/software-students-spring2024/3-python-package-exercise-bestswe/actions/workflows/build.yaml)

# Python Package Exercise

Welcome to just4Fun - a lighthearted Python package designed to bring a little joy and levity to developers' lives. This package includes four fun, interactive functions.

[PyPi Package](https://pypi.org/project/just4fun/0.1.1/)

This was an exercise to create a Python package, build it, test it, distribute it, and use it. See [instructions](./instructions.md) for details.

# Team Members

[Edison Chen](https://github.com/ebc5802)
[Natalie Wu](https://github.com/nawubyte)
[Chelsea Li](https://github.com/qiaoxixi1)
[Jacklyn Hu](https://github.com/Jacklyn22)

# Usage

### Installation
pip install just4fun

### Example Program
A sample program demonstrating all package functions is included. Run __main__.py to explore the functionalities of just4fun.

### To Test Functionality + Run Tests
pytest

# 4 Functions

### 8 Ball Predictions

Input = question for the 8 ball

Variations:

- If the input is too long, reject the question, the 8 ball doesn't want to think about it.

- If too many questions are asked, the 8 ball needs a break.

### Mood-Based Affirmations

Input = mood (i.e. happy or sad)

Variations:

- Will give you a compliment / affirmation based on your mood.

### Make Me Laugh

Input = output type (fun fact or joke)

Variations:

- Gives you a fun fact or a joke

### Copypasta

Input = ouptut type (text or image)

Variations:

- Text copypasta, image copypasta (image made up of characters / emojis in terminal)

